<div align="center">

  <h3 align="center">Faber Fireplace ITC v2</h3>

  <p align="center">
    A simple python library for controlling a Faber fireplace
  </p>
</div>
<br>
<br>
<br>

<!-- CONTRIBUTING -->
## Contributing

Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".




<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.

